pub struct GoogleCloudAiplatformV1ContainerRegistryDestination {
pub output_uri: Option<String>,
}Expand description
The Container Registry location for the container image.
This type is not used in any activity, and only used as part of another schema.
Fields
output_uri: Option<String>Required. Container Registry URI of a container image. Only Google Container Registry and Artifact Registry are supported now. Accepted forms: * Google Container Registry path. For example: gcr.io/projectId/imageName:tag. * Artifact Registry path. For example: us-central1-docker.pkg.dev/projectId/repoName/imageName:tag. If a tag is not specified, “latest” will be used as the default tag.