pub struct GoogleCloudAiplatformV1DataItemView {
pub has_truncated_annotations: Option<bool>,
pub annotations: Option<Vec<GoogleCloudAiplatformV1Annotation>>,
pub data_item: Option<GoogleCloudAiplatformV1DataItem>,
}Expand description
A container for a single DataItem and Annotations on it.
This type is not used in any activity, and only used as part of another schema.
Fields
has_truncated_annotations: Option<bool>True if and only if the Annotations field has been truncated. It happens if more Annotations for this DataItem met the request’s annotation_filter than are allowed to be returned by annotations_limit. Note that if Annotations field is not being returned due to field mask, then this field will not be set to true no matter how many Annotations are there.
annotations: Option<Vec<GoogleCloudAiplatformV1Annotation>>The Annotations on the DataItem. If too many Annotations should be returned for the DataItem, this field will be truncated per annotations_limit in request. If it was, then the has_truncated_annotations will be set to true.
data_item: Option<GoogleCloudAiplatformV1DataItem>The DataItem.