pub struct GoogleCloudAiplatformV1FeatureValueList {
pub values: Option<Vec<GoogleCloudAiplatformV1FeatureValue>>,
}Expand description
Container for list of values.
This type is not used in any activity, and only used as part of another schema.
Fields
values: Option<Vec<GoogleCloudAiplatformV1FeatureValue>>A list of feature values. All of them should be the same data type.