pub struct GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis {
pub anomaly_detection_baseline: Option<String>,
pub state: Option<String>,
}Expand description
Configuration of the Featurestore’s ImportFeature Analysis Based Monitoring. This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation.
This type is not used in any activity, and only used as part of another schema.
Fields
anomaly_detection_baseline: Option<String>The baseline used to do anomaly detection for the statistics generated by import features analysis.
state: Option<String>Whether to enable / disable / inherite default hebavior for import features analysis.