pub struct GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis {
pub disabled: Option<bool>,
pub staleness_days: Option<i32>,
pub monitoring_interval_days: Option<i32>,
}Expand description
Configuration of the Featurestore’s Snapshot Analysis Based Monitoring. This type of analysis generates statistics for each Feature based on a snapshot of the latest feature value of each entities every monitoring_interval.
This type is not used in any activity, and only used as part of another schema.
Fields
disabled: Option<bool>The monitoring schedule for snapshot analysis. For EntityType-level config: unset / disabled = true indicates disabled by default for Features under it; otherwise by default enable snapshot analysis monitoring with monitoring_interval for Features under it. Feature-level config: disabled = true indicates disabled regardless of the EntityType-level config; unset monitoring_interval indicates going with EntityType-level config; otherwise run snapshot analysis monitoring with monitoring_interval regardless of the EntityType-level config. Explicitly Disable the snapshot analysis based monitoring.
staleness_days: Option<i32>Customized export features time window for snapshot analysis. Unit is one day. Default value is 3 weeks. Minimum value is 1 day. Maximum value is 4000 days.
monitoring_interval_days: Option<i32>Configuration of the snapshot analysis based monitoring pipeline running interval. The value indicates number of days.