pub struct GoogleCloudAiplatformV1FindNeighborsResponseNeighbor {
pub datapoint: Option<GoogleCloudAiplatformV1IndexDatapoint>,
pub distance: Option<f64>,
pub sparse_distance: Option<f64>,
}Expand description
A neighbor of the query vector.
This type is not used in any activity, and only used as part of another schema.
Fields
datapoint: Option<GoogleCloudAiplatformV1IndexDatapoint>The datapoint of the neighbor. Note that full datapoints are returned only when “return_full_datapoint” is set to true. Otherwise, only the “datapoint_id” and “crowding_tag” fields are populated.
distance: Option<f64>The distance between the neighbor and the dense embedding query.
sparse_distance: Option<f64>The distance between the neighbor and the query sparse_embedding.