GoogleCloudAiplatformV1IndexDatapoint

Struct GoogleCloudAiplatformV1IndexDatapoint 

pub struct GoogleCloudAiplatformV1IndexDatapoint {
    pub sparse_embedding: Option<GoogleCloudAiplatformV1IndexDatapointSparseEmbedding>,
    pub crowding_tag: Option<GoogleCloudAiplatformV1IndexDatapointCrowdingTag>,
    pub numeric_restricts: Option<Vec<GoogleCloudAiplatformV1IndexDatapointNumericRestriction>>,
    pub datapoint_id: Option<String>,
    pub restricts: Option<Vec<GoogleCloudAiplatformV1IndexDatapointRestriction>>,
    pub feature_vector: Option<Vec<f32>>,
}
A datapoint of Index.

This type is not used in any activity, and only used as part of another schema.

Fields

sparse_embedding: Option<GoogleCloudAiplatformV1IndexDatapointSparseEmbedding>

Optional. Feature embedding vector for sparse index.

crowding_tag: Option<GoogleCloudAiplatformV1IndexDatapointCrowdingTag>

Optional. CrowdingTag of the datapoint, the number of neighbors to return in each crowding can be configured during query.

numeric_restricts: Option<Vec<GoogleCloudAiplatformV1IndexDatapointNumericRestriction>>

Optional. List of Restrict of the datapoint, used to perform “restricted searches” where boolean rule are used to filter the subset of the database eligible for matching. This uses numeric comparisons.

datapoint_id: Option<String>

Required. Unique identifier of the datapoint.

restricts: Option<Vec<GoogleCloudAiplatformV1IndexDatapointRestriction>>

Optional. List of Restrict of the datapoint, used to perform “restricted searches” where boolean rule are used to filter the subset of the database eligible for matching. This uses categorical tokens. See: https://cloud.google.com/vertex-ai/docs/matching-engine/filtering

feature_vector: Option<Vec<f32>>

Required. Feature embedding vector for dense index. An array of numbers with the length of [NearestNeighborSearchConfig.dimensions].