pub struct GoogleCloudAiplatformV1ListOptimalTrialsResponse {
pub optimal_trials: Option<Vec<GoogleCloudAiplatformV1Trial>>,
}Expand description
Response message for VizierService.ListOptimalTrials.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
optimal_trials: Option<Vec<GoogleCloudAiplatformV1Trial>>The pareto-optimal Trials for multiple objective Study or the optimal trial for single objective Study. The definition of pareto-optimal can be checked in wiki page. https://en.wikipedia.org/wiki/Pareto_efficiency