pub struct GoogleCloudAiplatformV1ListTensorboardRunsResponse {
pub tensorboard_runs: Option<Vec<GoogleCloudAiplatformV1TensorboardRun>>,
pub next_page_token: Option<String>,
}Expand description
Response message for TensorboardService.ListTensorboardRuns.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
tensorboard_runs: Option<Vec<GoogleCloudAiplatformV1TensorboardRun>>The TensorboardRuns mathching the request.
next_page_token: Option<String>A token, which can be sent as ListTensorboardRunsRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.