pub struct GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec {
pub max_trial_count: Option<i32>,
pub search_trial_job_spec: Option<GoogleCloudAiplatformV1CustomJobSpec>,
pub max_parallel_trial_count: Option<i32>,
pub max_failed_trial_count: Option<i32>,
}Expand description
Represent spec for search trials.
This type is not used in any activity, and only used as part of another schema.
Fields
max_trial_count: Option<i32>Required. The maximum number of Neural Architecture Search (NAS) trials to run.
search_trial_job_spec: Option<GoogleCloudAiplatformV1CustomJobSpec>Required. The spec of a search trial job. The same spec applies to all search trials.
max_parallel_trial_count: Option<i32>Required. The maximum number of trials to run in parallel.
max_failed_trial_count: Option<i32>The number of failed trials that need to be seen before failing the NasJob. If set to 0, Vertex AI decides how many trials must fail before the whole job fails.