pub struct GoogleCloudAiplatformV1NearestNeighborQuery {
pub embedding: Option<GoogleCloudAiplatformV1NearestNeighborQueryEmbedding>,
pub string_filters: Option<Vec<GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>>,
pub parameters: Option<GoogleCloudAiplatformV1NearestNeighborQueryParameters>,
pub neighbor_count: Option<i32>,
pub entity_id: Option<String>,
pub per_crowding_attribute_neighbor_count: Option<i32>,
pub numeric_filters: Option<Vec<GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter>>,
}Expand description
A query to find a number of similar entities.
This type is not used in any activity, and only used as part of another schema.
Fields
embedding: Option<GoogleCloudAiplatformV1NearestNeighborQueryEmbedding>Optional. The embedding vector that be used for similar search.
string_filters: Option<Vec<GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>>Optional. The list of string filters.
parameters: Option<GoogleCloudAiplatformV1NearestNeighborQueryParameters>Optional. Parameters that can be set to tune query on the fly.
neighbor_count: Option<i32>Optional. The number of similar entities to be retrieved from feature view for each query.
entity_id: Option<String>Optional. The entity id whose similar entities should be searched for. If embedding is set, search will use embedding instead of entity_id.
per_crowding_attribute_neighbor_count: Option<i32>Optional. Crowding is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than sper_crowding_attribute_neighbor_count of the k neighbors returned have the same value of crowding_attribute. It’s used for improving result diversity.
numeric_filters: Option<Vec<GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter>>Optional. The list of numeric filters.