pub struct GoogleCloudAiplatformV1NearestNeighborsNeighbor {
pub entity_key_values: Option<GoogleCloudAiplatformV1FetchFeatureValuesResponse>,
pub entity_id: Option<String>,
pub distance: Option<f64>,
}Expand description
A neighbor of the query vector.
This type is not used in any activity, and only used as part of another schema.
Fields
entity_key_values: Option<GoogleCloudAiplatformV1FetchFeatureValuesResponse>The attributes of the neighbor, e.g. filters, crowding and metadata Note that full entities are returned only when “return_full_entity” is set to true. Otherwise, only the “entity_id” and “distance” fields are populated.
entity_id: Option<String>The id of the similar entity.
distance: Option<f64>The distance between the neighbor and the query vector.