pub struct GoogleCloudAiplatformV1NetworkSpec {
pub subnetwork: Option<String>,
pub network: Option<String>,
pub enable_internet_access: Option<bool>,
}Expand description
Network spec.
This type is not used in any activity, and only used as part of another schema.
Fields
subnetwork: Option<String>The name of the subnet that this instance is in. Format: projects/{project_id_or_number}/regions/{region}/subnetworks/{subnetwork_id}
network: Option<String>The full name of the Google Compute Engine network
enable_internet_access: Option<bool>Whether to enable public internet access. Default false.