pub struct GoogleCloudAiplatformV1NotebookEucConfig {
pub bypass_actas_check: Option<bool>,
pub euc_disabled: Option<bool>,
}Expand description
The euc configuration of NotebookRuntimeTemplate.
This type is not used in any activity, and only used as part of another schema.
Fields
bypass_actas_check: Option<bool>Output only. Whether ActAs check is bypassed for service account attached to the VM. If false, we need ActAs check for the default Compute Engine Service account. When a Runtime is created, a VM is allocated using Default Compute Engine Service Account. Any user requesting to use this Runtime requires Service Account User (ActAs) permission over this SA. If true, Runtime owner is using EUC and does not require the above permission as VM no longer use default Compute Engine SA, but a P4SA.
euc_disabled: Option<bool>Input only. Whether EUC is disabled in this NotebookRuntimeTemplate. In proto3, the default value of a boolean is false. In this way, by default EUC will be enabled for NotebookRuntimeTemplate.