pub struct GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView {
pub entity_id: Option<String>,
pub data: Option<Vec<GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData>>,
}Expand description
Entity view with Feature values.
This type is not used in any activity, and only used as part of another schema.
Fields
entity_id: Option<String>ID of the requested entity.
data: Option<Vec<GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData>>Each piece of data holds the k requested values for one requested Feature. If no values for the requested Feature exist, the corresponding cell will be empty. This has the same size and is in the same order as the features from the header ReadFeatureValuesResponse.header.