pub struct GoogleCloudAiplatformV1ReadTensorboardBlobDataResponse {
pub blobs: Option<Vec<GoogleCloudAiplatformV1TensorboardBlob>>,
}Expand description
Response message for TensorboardService.ReadTensorboardBlobData.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
blobs: Option<Vec<GoogleCloudAiplatformV1TensorboardBlob>>Blob messages containing blob bytes.