GoogleCloudAiplatformV1ShieldedVmConfig

Struct GoogleCloudAiplatformV1ShieldedVmConfig 

pub struct GoogleCloudAiplatformV1ShieldedVmConfig {
    pub enable_secure_boot: Option<bool>,
}
A set of Shielded Instance options. See Images using supported Shielded VM features.

This type is not used in any activity, and only used as part of another schema.

Fields

enable_secure_boot: Option<bool>

Defines whether the instance has Secure Boot enabled. Secure Boot helps ensure that the system only runs authentic software by verifying the digital signature of all boot components, and halting the boot process if signature verification fails.