pub struct GoogleCloudAiplatformV1TokensInfo {
pub token_ids: Option<Vec<i64>>,
pub tokens: Option<Vec<Vec<u8>>>,
pub role: Option<String>,
}Expand description
Tokens info with a list of tokens and the corresponding list of token ids.
This type is not used in any activity, and only used as part of another schema.
Fields
token_ids: Option<Vec<i64>>A list of token ids from the input.
tokens: Option<Vec<Vec<u8>>>A list of tokens from the input.
role: Option<String>Optional. Optional fields for the role from the corresponding Content.