pub struct GoogleCloudAiplatformV1TunedModel {
pub model: Option<String>,
pub endpoint: Option<String>,
}Expand description
The Model Registry Model and Online Prediction Endpoint assiociated with this TuningJob.
This type is not used in any activity, and only used as part of another schema.
Fields
model: Option<String>Output only. The resource name of the TunedModel. Format: projects/{project}/locations/{location}/models/{model}.
endpoint: Option<String>Output only. A resource name of an Endpoint. Format: projects/{project}/locations/{location}/endpoints/{endpoint}.