GoogleCloudAiplatformV1UserActionReference

Struct GoogleCloudAiplatformV1UserActionReference 

pub struct GoogleCloudAiplatformV1UserActionReference {
    pub operation: Option<String>,
    pub method: Option<String>,
    pub data_labeling_job: Option<String>,
}
References an API call. It contains more information about long running operation and Jobs that are triggered by the API call.

This type is not used in any activity, and only used as part of another schema.

Fields

operation: Option<String>

For API calls that return a long running operation. Resource name of the long running operation. Format: projects/{project}/locations/{location}/operations/{operation}

method: Option<String>

The method name of the API RPC call. For example, “/google.cloud.aiplatform.{apiVersion}.DatasetService.CreateDataset”

data_labeling_job: Option<String>

For API calls that start a LabelingJob. Resource name of the LabelingJob. Format: projects/{project}/locations/{location}/dataLabelingJobs/{data_labeling_job}