pub struct GoogleCloudAiplatformV1IndexDatapointNumericRestriction {
pub value_int: Option<i64>,
pub op: Option<String>,
pub namespace: Option<String>,
pub value_float: Option<f32>,
pub value_double: Option<f64>,
}Expand description
This field allows restricts to be based on numeric comparisons rather than categorical tokens.
This type is not used in any activity, and only used as part of another schema.
Fields
value_int: Option<i64>Represents 64 bit integer.
op: Option<String>This MUST be specified for queries and must NOT be specified for datapoints.
namespace: Option<String>The namespace of this restriction. e.g.: cost.
value_float: Option<f32>Represents 32 bit float.
value_double: Option<f64>Represents 64 bit float.